==> haskell-hopenpgp-2.5.5-59-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-ErXGfOezHdF4GpbsmAWBC6
key: hOpenPGP-2.5.5-ErXGfOezHdF4GpbsmAWBC6
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.Types Codec.Encryption.OpenPGP.CFB
    Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: 6e876f420909a93fcb0e56f0bcde3570
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-ErXGfOezHdF4GpbsmAWBC6
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj binary-0.8.3.0
    binary-conduit-1.2.4.1-DSCo6XMtG3uAqe1LBOcDs5
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS containers-0.5.7.1
    crypto-cipher-types-0.0.9-4BaVA7C69Yr3PFsK4f4Qy0
    cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    incremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
    ixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
    lens-4.15.2-BxbTW4f5KkaK0a0gwsjHe2
    memory-0.14.5-8bv3NC3SoYTKu3JUzoaHbd
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    nettle-0.2.0-5dgBOmNmMaE4k019W9IqhH
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    newtype-0.2-6DnlyeREupYF8x0b7VMCgm
    openpgp-asciiarmor-0.1-Alp8PYDIsej9Y3uPSZRQCi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    securemem-0.1.9-6AAYl6PAm7KOCwhTX3JHZ
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wl-pprint-extras-3.5.0.5-GPBAFssOYCK64INbXekaCy
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.5.5-61-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-Afq62XcaexkDYwe09Zdm7u
key: hOpenPGP-2.5.5-Afq62XcaexkDYwe09Zdm7u
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.Types Codec.Encryption.OpenPGP.CFB
    Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: c98f741dcbf9ff4e3575a7d7612bed4b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-Afq62XcaexkDYwe09Zdm7u
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj binary-0.8.3.0
    binary-conduit-1.2.4.1-DSCo6XMtG3uAqe1LBOcDs5
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS containers-0.5.7.1
    crypto-cipher-types-0.0.9-KCUUibYwQfd3mN2Luf0nrN
    cryptonite-0.22-BghVPg0sVunAfXbG7gt71d
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    incremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
    ixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
    lens-4.15.2-Btt200f9Hc914EBmV4spTa
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    nettle-0.2.0-AOWpnprs1h3Ipr0Si7Ri5C
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    newtype-0.2-6DnlyeREupYF8x0b7VMCgm
    openpgp-asciiarmor-0.1-Alp8PYDIsej9Y3uPSZRQCi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    securemem-0.1.9-EejLErvjcTFDEKlSmM4Et1
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wl-pprint-extras-3.5.0.5-GPBAFssOYCK64INbXekaCy
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
